@@ -78,3 +78,26 @@ test_that("page_sidebar()", {
   )
 
 })
+
+test_that("save_html() works on components and pages with a custom theme", {
+  withr::local_options(list(htmltools.dir.version = FALSE))
+
+  withr::with_tempdir({
+    save_html(
+      card("A simple card"),
+      "card.html"
+    )
+    expect_snapshot_file("card.html")
+  })
+
+  withr::with_tempdir({
+    save_html(
+      page(
+        theme = bs_remove(bs_theme(), "bs3compat"),
+        "A simple page without bs3compat dependencies"
+      ),
+      "modern-page.html"
+    )
+    expect_snapshot_file("modern-page.html")
+  })
+})
